@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-import os, sys, ast, json, glob, platform, subprocess, random, stripe, threading
+import os, sys, ast, json, glob, platform, subprocess, random, stripe, threading, time
 
 # inc imports.
 from fil3s import Files, Formats
