@@ -458,6 +458,8 @@ class RestAPI(object):
 		uid=None,
 		# the plan from the api key.
 		plan=None,
+		# free on sign-up date.
+		trial=True,
 	):
 
 		# check info.
@@ -476,9 +478,13 @@ class RestAPI(object):
 		if response["error"] != None: return response
 		data = response["data"]
 		timestamp = response["data"]["timestamp"]
+		date = Formats.Date()
+
+		# check trial.
+		if trial and data["signed_up"] == date.date:
+			return r3sponse.success_response("Successfully verified the rate limit.")
 
 		# check timestamp.
-		date = Formats.Date()
 		success = False
 		if timestamp == None:
 			success = True
